#!/bin/sh
#
# Startup script for the CLUSTERPRO information base
#

#
# main()
#

# Source function library.
if [ -f /etc/rc.d/init.d/functions ]
then
	. /etc/rc.d/init.d/functions
elif [ -f /etc/rc.status ]
then
	. /etc/rc.status
fi

. /opt/nec/clusterpro/bin/clpfunctions

PATH=/sbin:/bin:/usr/sbin:/usr/bin:/opt/nec/clusterpro/bin
LD_LIBRARY_PATH=/opt/nec/clusterpro/lib
MALLOC_CHECK_=0
LANG=C

export PATH
export LD_LIBRARY_PATH
export MALLOC_CHECK_
export LANG
# See how we were called.
case "$1" in
  start)
	targetos=`/bin/uname`
	clp_filedel "$1" init_ib $targetos
	clp_logwrite "$1" "clusterpro_information base start process start." init_ib
	
	#
	cd /opt/nec/clusterpro/bin

	#
	if [ "$targetos" = "SunOS" ]
	then
		echo "Starting clusterpro information base: \c"
	else
		logging=`clpcfget -g /root/event/container/logging` 
		cfget_ret=$?
		if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
		then
			echo -n "Starting clusterpro information base: " > /dev/null 2>&1
		else
			echo -n "Starting clusterpro information base: "
		fi
	fi

	#
	clp_logwrite "$1" "clppidof start." init_ib
	pids=`/opt/nec/clusterpro/bin/clppidof /opt/nec/clusterpro/bin/clpmonp --ibsv 2>&1`
	clp_logwrite "$1" "clppidof end.(pids=${pids})" init_ib

	if [ "$pids" != "" ]
	then
		clp_logwrite "$1" "information base already exist." init_ib
		clp_logwrite "$1" "clusterpro_ib start process end." init_ib
		if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
		then
			clp_success $targetos > /dev/null 2>&1
		else
			clp_success $targetos
		fi
		exit 0
	fi

	# starting clusterpro information base
	clp_logwrite "$1" "information base start process start." init_ib
	./clpmonp --ibsv -a 2 -r 0 -w 0 > /dev/null 2>&1
	monp_ret=$?
	clp_logwrite "$1" "information base start process end.("$monp_ret")" init_ib

	if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
	then
		clp_checkerr "$monp_ret" $targetos > /dev/null 2>&1
	else
		clp_checkerr "$monp_ret" $targetos
	fi
	chk_ret=$?
	if [ "$chk_ret" = "1" ]
	then
		clp_logwrite "$1" "clusterpro_ib start process end." init_ib
		exit 0
	fi

	clp_logwrite "$1" "clusterpro_ib start process end." init_ib
	;;
  stop)
	targetos=`/bin/uname`

	clp_filedel "$1" init_ib $targetos
	clp_logwrite "$1" "clusterpro_ib stop process start." init_ib

	#
	if [ "$targetos" = "SunOS" ]
	then
		echo "Shutting down clusterpro information base: \c"
	else
		logging=`clpcfget -g /root/event/container/logging` 
		cfget_ret=$?
		if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
		then
			echo -n "Shutting down clusterpro information base: " > /dev/null 2>&1
		else
			echo -n "Shutting down clusterpro information base: "
		fi
	fi

	#
	cd /opt/nec/clusterpro/bin

	#
	clp_logwrite "$1" "clppidof start." init_ib
	pids=`/opt/nec/clusterpro/bin/clppidof /opt/nec/clusterpro/bin/clpmonp --ibsv 2>&1`
	clp_logwrite "$1" "clppidof end.(pids=${pids})" init_ib
	
	if [ "$pids" != "" ]
	then
		# shutting down clusterpro information base
		clp_logwrite "$1" "information base stop process start." init_ib
		if [ "$targetos" = "SunOS" ]
		then
			kill -17 "$pids" 2>/dev/null
			kill_ret=$?
		else
			kill -12 "$pids" 2>/dev/null
			kill_ret=$?
		fi
		clp_logwrite "$1" "information base stop process end.("$kill_ret")" init_ib

		i=0
		while [ "$i" -lt "30" ]
		do
			clp_logwrite "$1" "clppidof2 start." init_ib
			pids=`/opt/nec/clusterpro/bin/clppidof /opt/nec/clusterpro/bin/clpmonp --ibsv 2>&1`
			clp_logwrite "$1" "clppidof2 end.(pids=${pids})" init_ib
			
			if [ "$pids" = "" ]
			then
				clp_logwrite "$1" "information base stop success." init_ib
				if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
				then
					clp_success $targetos > /dev/null 2>&1
				else
					clp_success $targetos
				fi

				clp_logwrite "$1" "clusterpro_ib stop process end." init_ib
				exit 0
			fi

			sleep 1
			i=`expr "$i" + 1`
		done
		
		clp_logwrite "$1" "information base stop timeout." init_ib
	else
		clp_logwrite "$1" "information base not exist." init_ib
	fi
	
	clp_logwrite "$1" "clusterpro_ib stop process end." init_ib
	if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
	then
		clp_success $targetos > /dev/null 2>&1
	else
		clp_success $targetos
	fi
	exit 0
	;;
  restart)
	$0 stop
	if [ "$?" != "0" ]
	then
		exit 1
	fi

	sleep 1
	$0 start
	;;
  status)
	targetos=`/bin/uname`
	if [ "$targetos" = "SunOS" ]
	then
		clp_status_s clpibsv
	else
		clp_status clpibsv
	fi
	;;
  *)
	echo "Usage: $0 {start|stop|restart|status}"
	exit 1
	;;
esac

exit 0
